@@ -1,12 +1,12 @@
-/*
- *  $Id: 6251568fe58fba1cd06f0a27d758c0f3b75f563e $
+/**
+ * \file defFind.c
  *
- *  Time-stamp:        "2010-02-24 08:43:07 bkorb"
+ *  Time-stamp:        "2011-01-20 16:23:20 bkorb"
  *
  *  This module locates definitions.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -30,7 +30,7 @@ struct defEntryList {
 };
 typedef struct defEntryList tDefEntryList;
 
-tSCC zNameRef[]   = "Ill formed name ``%s'' in %s line %d\n";
+static char const zNameRef[] = "Ill formed name ``%s'' in %s line %d\n";
 
 typedef struct hash_name_s hash_name_t;
 struct hash_name_s {
@@ -43,25 +43,24 @@ static int hash_table_ct = 0;
 
 static char zDefinitionName[ AG_PATH_MAX ];
 
-static tDefEntry* findEntryByIndex( tDefEntry* pE, char* pzScan );
+static tDefEntry* findEntryByIndex(tDefEntry* pE, char* pzScan);
 
 #define ILLFORMEDNAME() \
-    AG_ABEND( aprf( zNameRef, zDefinitionName, \
-              pCurTemplate->pzTplFile, pCurMacro->lineNo ));
-
+    AG_ABEND(aprf(zNameRef, zDefinitionName, \
+              pCurTemplate->pzTplFile, pCurMacro->lineNo));
 
 /* = = = START-STATIC-FORWARD = = = */
 static tDefEntry*
-findEntryByIndex( tDefEntry* pE, char* pzScan );
+findEntryByIndex(tDefEntry* pE, char* pzScan);
 
 static void
-addResult( tDefEntry* pDE, tDefEntryList* pDEL );
+addResult(tDefEntry* pDE, tDefEntryList* pDEL);
 
 static size_t
-badName( char* pzD, char const* pzS, size_t srcLen );
+badName(char* pzD, char const* pzS, size_t srcLen);
 
 static tDefEntry*
-defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed );
+find_def(char * pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed);
 
 static int
 hash_string(unsigned char const * pz);
@@ -69,12 +68,12 @@ hash_string(unsigned char const * pz);
 static void
 stringAdd(char const * pz);
 
-static tDefEntry**
-entryListSearch( char* pzName, tDefCtx* pDefCtx );
+static tDefEntry **
+get_def_list(char* pzName, tDefCtx* pDefCtx);
 /* = = = END-STATIC-FORWARD = = = */
 
 static tDefEntry*
-findEntryByIndex( tDefEntry* pE, char* pzScan )
+findEntryByIndex(tDefEntry* pE, char* pzScan)
 {
     int  idx;
 
@@ -103,7 +102,7 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
      */
     if (IS_DEC_DIGIT_CHAR(*pzScan)) {
         char* pz;
-        idx = strtol( pzScan, &pz, 0 );
+        idx = strtol(pzScan, &pz, 0);
 
         /*
          *  Skip over any trailing space and make sure we have a closer
@@ -132,7 +131,7 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
         {
             char  svch = *pzScan;
             *pzScan = NUL;
-            pzVal   = getDefine( pzDef, AG_TRUE );
+            pzVal   = getDefine(pzDef, AG_TRUE);
             *pzScan = svch;
         }
 
@@ -149,7 +148,7 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
         if ((pzVal == NULL) || (*pzVal == NUL))
             return NULL;
 
-        idx = strtol( pzVal, &pzDef, 0 );
+        idx = strtol(pzVal, &pzDef, 0);
 
         /*
          *  Make sure we got a legal number
@@ -180,13 +179,13 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
  *              list of found definitions (reallocating list size as needed).
  */
 static void
-addResult( tDefEntry* pDE, tDefEntryList* pDEL )
+addResult(tDefEntry* pDE, tDefEntryList* pDEL)
 {
     if (++(pDEL->usedCt) > pDEL->allocCt) {
         pDEL->allocCt += pDEL->allocCt + 8; /* 8, 24, 56, ... */
         pDEL->papDefEntry = (tDefEntry**)
-            AGREALOC( (void*)pDEL->papDefEntry, pDEL->allocCt * sizeof( void* ),
-                      "added find result" );
+            AGREALOC((void*)pDEL->papDefEntry, pDEL->allocCt * sizeof(void*),
+                     "added find result");
     }
 
     pDEL->papDefEntry[ pDEL->usedCt-1 ] = pDE;
@@ -194,12 +193,12 @@ addResult( tDefEntry* pDE, tDefEntryList* pDEL )
 
 
 static size_t
-badName( char* pzD, char const* pzS, size_t srcLen )
+badName(char* pzD, char const* pzS, size_t srcLen)
 {
-    memcpy( (void*)pzD, (void*)pzS, srcLen );
-    pzD[ srcLen ] = NUL;
-    fprintf( pfTrace, zNameRef, pzD,
-             pCurTemplate->pzTplFile, pCurMacro->lineNo );
+    memcpy((void*)pzD, (void*)pzS, srcLen);
+    pzD[srcLen] = NUL;
+    fprintf(pfTrace, zNameRef, pzD,
+             pCurTemplate->pzTplFile, pCurMacro->lineNo);
     return srcLen + 1;
 }
 
@@ -210,19 +209,19 @@ badName( char* pzD, char const* pzS, size_t srcLen )
  *  forms a valid AutoGen compound definition name.
  *  We leave legally when:
  *  1.  the state is "CN_NAME_ENDED", AND
- *  2.  We stumble into a character that is not either '[' or '.'
+ *  2.  We stumble into a character that is not either '[' or name_sep_ch
  *      (always skipping white space).
  *  We start in CN_START.
  */
 LOCAL int
-canonicalizeName( char* pzD, char const* pzS, int srcLen )
+canonicalizeName(char* pzD, char const* pzS, int srcLen)
 {
     typedef enum {
         CN_START_NAME = 0,   /* must find a name */
-        CN_NAME_ENDED,       /* must find '[' or '.' or we end */
+        CN_NAME_ENDED,       /* must find '[' or name_sep_ch or we end */
         CN_INDEX,            /* must find name, number, '$' or ']' */
         CN_INDEX_CLOSE,      /* must find ']' */
-        CN_INDEX_ENDED       /* must find '.' or we end */
+        CN_INDEX_ENDED       /* must find name_sep_ch or we end */
     } teConState;
 
     teConState state = CN_START_NAME;
@@ -232,8 +231,8 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
     size_t      stLen = srcLen;
 
     /*
-     *  Before anything, skip a leading '.' as a special hack to force
-     *  a current context lookup.
+     *  Before anything, skip a leading name_sep_ch as a special hack
+     *  to force a current context lookup.
      */
     while (IS_WHITESPACE_CHAR(*pzS )) {
         if (--srcLen <= 0) {
@@ -243,8 +242,8 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
         pzS++;
     }
 
-    if (*pzS == '.') {
-        *(pzD++) = '.';
+    if (*pzS == name_sep_ch) {
+        *(pzD++) = name_sep_ch;
         pzS++;
     }
 
@@ -265,7 +264,7 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
     switch (state) {
     case CN_START_NAME:
         if (! IS_VAR_FIRST_CHAR(*pzS))
-            return badName( pzDst, pzOri, stLen );
+            return badName(pzDst, pzOri, stLen);
         state = CN_NAME_ENDED;  /* we found the start of our first name */
         break;  /* fall through to name/number consumption code */
 
@@ -276,10 +275,12 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
             state = CN_INDEX;
             break;
 
-        case '.':
-            *(pzD++) = '.';
-            state = CN_START_NAME;
-            break;
+        case '.': case '/':
+            if (pzS[-1] == name_sep_ch) {
+                *(pzD++) = name_sep_ch;
+                state = CN_START_NAME;
+                break;
+            }
 
         default:
             /* legal exit -- we have a name already */
@@ -288,7 +289,7 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
         }
 
         if (--srcLen <= 0)
-            return badName( pzDst, pzOri, stLen );
+            return badName(pzDst, pzOri, stLen);
         goto nextSegment;
 
     case CN_INDEX:
@@ -319,7 +320,7 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
          */
         if (*pzS == '$') {
             if (--srcLen < 0)
-                return badName( pzDst, pzOri, stLen );
+                return badName(pzDst, pzOri, stLen);
 
             *(pzD++) = *(pzS++);
             goto nextSegment;
@@ -331,7 +332,7 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
          *  Nothing else is okay.
          */
         if ((*(pzD++) = *(pzS++)) != ']')
-            return badName( pzDst, pzOri, stLen );
+            return badName(pzDst, pzOri, stLen);
 
         if (--srcLen <= 0) {
             *pzD = NUL;
@@ -341,7 +342,7 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
         goto nextSegment;
 
     case CN_INDEX_ENDED:
-        if ((*pzS != '.') || (--srcLen < 0)) {
+        if ((*pzS != name_sep_ch) || (--srcLen < 0)) {
             *pzD = NUL;
             return srcLen;
         }
@@ -357,7 +358,7 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
      *  Whatever, the next token must be a name or a number.
      */
     assert((state == CN_NAME_ENDED) || (state == CN_INDEX_CLOSE));
-    assert( IS_ALPHANUMERIC_CHAR(*pzS));
+    assert(IS_ALPHANUMERIC_CHAR(*pzS));
 
     /*
      *  Copy the name/number.  We already know the first character is valid.
@@ -366,9 +367,9 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
     while (IS_VALUE_NAME_CHAR(*pzS)) {
         char ch = *(pzS++);
         if ((state != CN_INDEX_CLOSE) && IS_UPPER_CASE_CHAR(ch))
-            *(pzD++) = tolower( ch );
+            *(pzD++) = tolower(ch);
 
-        else switch ( ch ) { /* force the separator chars to be '_' */
+        else switch (ch) { /* force the separator chars to be '_' */
         case '-':
         case '^':
             *(pzD++) = '_';
@@ -388,9 +389,7 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
 }
 
 
-/*
- *  findDefEntry
- *
+/**
  *  Find the definition entry for the name passed in.
  *  It is okay to find block entries IFF they are found on the
  *  current level.  Once you start traversing up the tree,
@@ -399,11 +398,11 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen )
  *  to traverse the list of twins).
  */
 static tDefEntry*
-defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
+find_def(char * pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed)
 {
-    char*        pcBrace;
-    char         breakCh;
-    tDefEntry*   pE;
+    char *       brace;
+    char         br_ch;
+    tDefEntry *  ent;
     ag_bool      dummy;
     ag_bool      noNesting    = AG_FALSE;
 
@@ -416,32 +415,32 @@ defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
      *  an index yet).
      */
     if (nestingDepth == 0) {
-        canonicalizeName( zDefinitionName, pzName, (int)strlen( pzName ));
+        canonicalizeName(zDefinitionName, pzName, (int)strlen(pzName));
         pzName = zDefinitionName;
 
         if (pIsIndexed != NULL)
              *pIsIndexed = AG_FALSE;
         else pIsIndexed  = &dummy;
 
-        if (*pzName == '.') {
+        if (*pzName == name_sep_ch) {
             noNesting = AG_TRUE;
             pzName++;
         }
     }
 
-    pcBrace  = pzName + strcspn( pzName, "[." );
-    breakCh  = *pcBrace;
-    *pcBrace = NUL;
+    brace  = pzName + strcspn(pzName, "[.");
+    br_ch  = *brace;
+    *brace = NUL;
 
-    if (breakCh == '[') *pIsIndexed = AG_TRUE;
+    if (br_ch == '[') *pIsIndexed = AG_TRUE;
 
     for (;;) {
         /*
          *  IF we are at the end of the definitions (reached ROOT),
          *  THEN it is time to bail out.
          */
-        pE = pDefCtx->pDefs;
-        if (pE == NULL)
+        ent = pDefCtx->pDefs;
+        if (ent == NULL)
             return NULL;
 
         do  {
@@ -449,11 +448,11 @@ defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
              *  IF the name matches
              *  THEN break out of the double loop
              */
-            if (strcmp( pE->pzDefName, pzName ) == 0)
+            if (strcmp(ent->pzDefName, pzName) == 0)
                 goto found_def_entry;
 
-            pE = pE->pNext;
-        } while (pE != NULL);
+            ent = ent->pNext;
+        } while (ent != NULL);
 
         /*
          *  IF we are nested, then we cannot change the definition level.
@@ -471,58 +470,73 @@ defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
     } found_def_entry:;
 
     /*
-     *  At this point, we have found the entry that matches the supplied
-     *  name, up to the '[' or '.' or NUL character.  It *must* be one of
+     *  At this point, we have found the entry that matches the supplied name,
+     *  up to the '[' or name_sep_ch or NUL character.  It *must* be one of
      *  those three characters.
      */
-    *pcBrace = breakCh;
+    *brace = br_ch;
 
-    switch (breakCh) {
+    switch (br_ch) {
     case NUL:
-        return pE;
+        return ent;
 
     case '[':
         /*
          *  We have to find a specific entry in a list.
          */
-        while (IS_WHITESPACE_CHAR(*++pcBrace )) ;
+        while (IS_WHITESPACE_CHAR(*++brace )) ;
 
-        pE = findEntryByIndex( pE, pcBrace );
-        if (pE == NULL)
-            return pE;
+        ent = findEntryByIndex(ent, brace);
+        if (ent == NULL)
+            return ent;
 
         /*
          *  We must find the closing brace, or there is an error
          */
-        pcBrace = strchr( pcBrace, ']' );
-        if (pcBrace == NULL)
+        brace = strchr(brace, ']');
+        if (brace == NULL)
             ILLFORMEDNAME();
 
         /*
-         *  IF we are at the end of the definition,
-         *  THEN return what we found
+         *  What follows the closing brace?  IF we are at the end of the
+         *  definition, THEN return what we found.  However, if there's
+         *  another name, then we have to go look that one up, too.
          */
-        switch (*++pcBrace) {
+        switch (*++brace) {
         case NUL:
-            return pE;
+            return ent;
 
-        case '.':
-            break;
+        case '.': case '/':
+            /*
+             *  Which one?  One is valid, the other not and it is not known
+             *  at compile time.
+             */
+            if (*brace == name_sep_ch) {
+                pzName = brace + 1;
+                break;
+            }
+            /* FALLTHROUGH */
 
         default:
             ILLFORMEDNAME();
         }
-        /* FALLTHROUGH */
-
-    case '.':
-        /*
-         *  It is a segmented value name.  Set the name pointer
-         *  to the next segment and search starting from the newly
-         *  available set of definitions.
-         */
-        pzName = pcBrace + 1;
         break;
 
+    case '.': case '/':
+        if (br_ch == name_sep_ch) {
+            /*
+             *  Which one?  One is valid, the other not and it is not known
+             *  at compile time.
+             *
+             *  It is a segmented value name.  Set the name pointer
+             *  to the next segment and search starting from the newly
+             *  available set of definitions.
+             */
+            pzName = brace + 1;
+            break;
+        }
+        /* FALLTHROUGH */
+
     default:
         ILLFORMEDNAME();
     }
@@ -530,7 +544,7 @@ defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
     /*
      *  We cannot find a member of a non-block type macro definition.
      */
-    if (pE->valType != VALTYP_BLOCK)
+    if (ent->valType != VALTYP_BLOCK)
         return NULL;
 
     /*
@@ -542,20 +556,20 @@ defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
     {
         tDefCtx ctx = { NULL, &currDefCtx };
 
-        ctx.pDefs = pE->val.pDefEntry;
+        ctx.pDefs = ent->val.pDefEntry;
 
         for (;;) {
             tDefEntry* res;
 
-            res = defEntrySearch( pzName, &ctx, pIsIndexed );
-            if ((res != NULL) || (breakCh == '[')) {
+            res = find_def(pzName, &ctx, pIsIndexed);
+            if ((res != NULL) || (br_ch == '[')) {
                 nestingDepth--;
                 return res;
             }
-            pE = pE->pTwin;
-            if (pE == NULL)
+            ent = ent->pTwin;
+            if (ent == NULL)
                 break;
-            ctx.pDefs = pE->val.pDefEntry;
+            ctx.pDefs = ent->val.pDefEntry;
         }
     }
 
@@ -609,7 +623,7 @@ stringAdd(char const * pz)
      *  Save only the last component of the name, sans any index, too.
      */
     {
-        char const * p = strrchr(pz, '.');
+        char const * p = strrchr(pz, name_sep_ch);
         if (p != NULL)
             pz = p + 1;
         p = strchr(pz, '[');
@@ -660,11 +674,11 @@ stringAdd(char const * pz)
 }
 
 LOCAL tDefEntry*
-findDefEntry( char* pzName, ag_bool* pIsIndexed )
+findDefEntry(char * pzName, ag_bool* pIsIndexed)
 {
     if (HAVE_OPT(USED_DEFINES))
         stringAdd(pzName);
-    return defEntrySearch( pzName, &currDefCtx, pIsIndexed );
+    return find_def(pzName, &currDefCtx, pIsIndexed);
 }
 
 
@@ -697,17 +711,15 @@ print_used_defines(void)
 }
 
 
-/*
- *  entryListSearch
- *
- *  Find the definition entry for the name passed in.  It is okay to find
+/**
+ *  Find the definition entries for the name passed in.  It is okay to find
  *  block entries IFF they are found on the current level.  Once you start
  *  traversing up the tree, the macro must be a text macro.  Return an
  *  indicator saying if the element has been indexed (so the caller will
  *  not try to traverse the list of twins).
  */
-static tDefEntry**
-entryListSearch( char* pzName, tDefCtx* pDefCtx )
+static tDefEntry **
+get_def_list(char* pzName, tDefCtx* pDefCtx)
 {
     static tDefEntryList defList = { 0, 0, NULL, 0 };
 
@@ -723,7 +735,7 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
      *  an index yet).
      */
     if (defList.nestLevel == 0) {
-        if (*pzName == '.') {
+        if (*pzName == name_sep_ch) {
             noNesting = AG_TRUE;
             while (IS_WHITESPACE_CHAR(*++pzName)) ;
         }
@@ -732,15 +744,17 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
             strncpy(zDefinitionName, pzName, sizeof(zDefinitionName) - 1);
             zDefinitionName[ sizeof(zDefinitionName) - 1] = NUL;
             ILLFORMEDNAME();
-            return NULL;
         }
 
-        canonicalizeName( zDefinitionName, pzName, (int)strlen( pzName ));
+        canonicalizeName(zDefinitionName, pzName, (int)strlen(pzName));
         pzName = zDefinitionName;
         defList.usedCt = 0;
     }
 
-    pcBrace  = pzName + strcspn( pzName, "[." );
+    {
+        char sep_buf[3] = { '[', name_sep_ch, NUL };
+        pcBrace = pzName + strcspn(pzName, sep_buf);
+    }
     breakCh  = *pcBrace;
     *pcBrace = NUL;
 
@@ -770,7 +784,7 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
              *  IF the name matches
              *  THEN go add it, plus all its twins
              */
-            if (strcmp( pE->pzDefName, pzName ) == 0)
+            if (strcmp(pE->pzDefName, pzName) == 0)
                 goto found_def_entry;
 
             pE = pE->pNext;
@@ -792,8 +806,8 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
     } found_def_entry:;
 
     /*
-     *  At this point, we have found the entry that matches the supplied
-     *  name, up to the '[' or '.' or NUL character.  It *must* be one of
+     *  At this point, we have found the entry that matches the supplied name,
+     *  up to the '[' or name_sep_ch or NUL character.  It *must* be one of
      *  those three characters.
      */
     *pcBrace = breakCh;
@@ -801,7 +815,7 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
     switch (breakCh) {
     case NUL:
         do  {
-            addResult( pE, &defList );
+            addResult(pE, &defList);
             pE = pE->pTwin;
         } while (pE != NULL);
         goto returnResult;
@@ -812,14 +826,14 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
          */
         while (IS_WHITESPACE_CHAR(*++pcBrace)) ;
 
-        pE = findEntryByIndex( pE, pcBrace );
+        pE = findEntryByIndex(pE, pcBrace);
         if (pE == NULL)
             goto returnResult;
 
         /*
          *  We must find the closing brace, or there is an error
          */
-        pcBrace = strchr( pcBrace, ']' );
+        pcBrace = strchr(pcBrace, ']');
         if (pcBrace == NULL)
             ILLFORMEDNAME();
 
@@ -831,67 +845,71 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
         case NUL:
             goto returnResult;
 
-        case '.':
-            break;
+        case '.': case '/':
+            /*
+             *  Which one?  One is valid, the other not and it is not known
+             *  at compile time.
+             */
+            if (*pcBrace == name_sep_ch)
+                break;
+            /* FALLTHROUGH */
 
         default:
             ILLFORMEDNAME();
         }
-        /* FALLTHROUGH */
-
-    case '.':
-        /*
-         *  It is a segmented value name.  Set the name pointer
-         *  to the next segment and search starting from the newly
-         *  available set of definitions.
-         */
         pzName = pcBrace + 1;
         break;
 
+    case '.': case '/':
+        if (breakCh == name_sep_ch) {
+            /*
+             *  Which one?  One is valid, the other not and it is not known
+             *  at compile time.
+             *
+             *  It is a segmented value name.  Set the name pointer to the
+             *  next segment and search starting from the newly available set
+             *  of definitions.
+             */
+            pzName = pcBrace + 1;
+            break;
+        }
+
     default:
         ILLFORMEDNAME();
     }
 
     /*
-     *  We cannot find a member of a non-block type macro definition.
-     */
-    if (pE->valType != VALTYP_BLOCK)
-        return NULL;
-
-    /*
-     *  Loop through all the twins of the entry.  We ignore twins if we just
-     *  used a subscript.
+     *  Loop through all the twins of the entry.  We only look once if we used
+     *  a subscript.  Ignore any entry types that are not "Blocks" because
+     *  text entries won't have any children.
      */
     defList.nestLevel++;
-    {
-        tDefCtx ctx = { NULL, &currDefCtx };
+    do  {
+        tDefCtx ctx = { pE->val.pDefEntry, &currDefCtx };
 
-        ctx.pDefs = pE->val.pDefEntry;
+        if (pE->valType == VALTYP_BLOCK)
+            (void)get_def_list(pzName, &ctx);
+
+        if (breakCh == '[')
+            break;
+
+        pE = pE->pTwin;
+    } while (pE != NULL);
 
-        for (;;) {
-            (void)entryListSearch( pzName, &ctx );
-            if (breakCh == '[')
-                break;
-            pE = pE->pTwin;
-            if (pE == NULL)
-                break;
-            ctx.pDefs = pE->val.pDefEntry;
-        }
-    }
     defList.nestLevel--;
 
  returnResult:
     if (defList.nestLevel == 0)
-        addResult( NULL, &defList );
+        addResult(NULL, &defList);
 
     return defList.papDefEntry;
 }
 
 
 LOCAL tDefEntry**
-findEntryList( char* pzName )
+findEntryList(char* pzName)
 {
-    return entryListSearch( pzName, &currDefCtx );
+    return get_def_list(pzName, &currDefCtx);
 }
 /*
  * Local Variables:
