@@ -2,12 +2,12 @@
 /**
  *  \file expFormat.c
  *
- *  Time-stamp:        "2010-12-02 14:22:08 bkorb"
+ *  Time-stamp:        "2011-01-20 16:15:53 bkorb"
  *
  *  This module implements formatting expression functions.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -103,12 +103,12 @@ static char const zDne2[] = "%6$s"
 "%1$sFrom the definitions    %4$s\n"
 "%1$sand the template file   %5$s";
 
-tSCC zOwnLen[]  = "owner length";
-tSCC zPfxLen[]  = "prefix length";
-tSCC zProgLen[] = "program name length";
-tSCC zPfxMsg[]  = "%s may not exceed %d chars\n";
+static char const zOwnLen[]  = "owner length";
+static char const zPfxLen[]  = "prefix length";
+static char const zProgLen[] = "program name length";
+static char const zPfxMsg[]  = "%s may not exceed %d chars\n";
 
-tSCC zFmtAlloc[] = "asprintf allocation";
+static char const zFmtAlloc[] = "asprintf allocation";
 
 /*=gfunc dne
  *
@@ -148,53 +148,59 @@ tSCC zFmtAlloc[] = "asprintf allocation";
 SCM
 ag_scm_dne(SCM prefix, SCM first, SCM opt)
 {
-    int      noDate   = 0;
-    char     zScribble[ SCRIBBLE_SIZE ];
-    char*    pzRes;
-    tCC*     pzFirst  = zNil;
-    SCM      res;
-    size_t   pfxLen   = AG_SCM_STRLEN(prefix);
-    tCC*     pzPrefix = ag_scm2zchars(prefix, "dne-prefix");
+    char const *  date_str;
+    char const *  pzRes;
+    char const *  pzFirst;
+    size_t        pfxLen;
+    char const *  pzPrefix;
+    SCM           res;
+
+    if (! AG_SCM_STRING_P(prefix))
+        return SCM_UNDEFINED;
+
+    date_str = NULL;
+    pzFirst  = zNil;
+    pfxLen   = AG_SCM_STRLEN(prefix);
+    pzPrefix = ag_scm2zchars(prefix, "dne-prefix");
 
     /*
      *  Check for the ``-d'' option
      */
     if ((pfxLen == 2) && (strncmp(pzPrefix, "-d", (size_t)2) == 0)) {
-        noDate   = 1;
+        date_str = zNil;
         pfxLen   = AG_SCM_STRLEN(first);
         pzPrefix = ag_scm2zchars(first, "dne-prefix");
         first    = opt;
     }
 
-    if (pfxLen > SCRIBBLE_SIZE )
-        AG_ABEND(aprf(zPfxMsg, zPfxLen, SCRIBBLE_SIZE));
-
     /*
      *  IF we also have a 'first' prefix string,
      *  THEN we set it to something other than ``zNil'' and deallocate later.
      */
-    if (AG_SCM_STRING_P(first)) {
-        int len = AG_SCM_STRLEN(first);
-        if (len >= SCRIBBLE_SIZE)
-            AG_ABEND(aprf(zPfxMsg, zPfxLen, SCRIBBLE_SIZE));
-
+    if (AG_SCM_STRING_P(first))
         pzFirst = aprf(ENABLED_OPT(WRITABLE) ? "%s\n" : zDne1,
                        ag_scm2zchars(first, "first-prefix"), pzPrefix);
-    }
 
-    if (noDate) {
-        zScribble[0] = NUL;
-    } else {
+    if (date_str == NULL) {
         static char const tim_fmt[] =
             "  %B %e, %Y at %r by AutoGen " AUTOGEN_VERSION;
-        time_t    curTime = time(NULL);
-        struct tm*  pTime = localtime(&curTime);
-        strftime(zScribble, (size_t)SCRIBBLE_SIZE, tim_fmt, pTime);
+
+        size_t const  tsiz = sizeof(tim_fmt) + sizeof("september") * 2;
+        time_t     curTime = time(NULL);
+        struct tm*   pTime = localtime(&curTime);
+
+        date_str = ag_scribble(tsiz);
+        strftime((char *)date_str, tsiz, tim_fmt, pTime);
     }
 
     {
-        char const* pz;
-        tFpStack*   pfp = pCurFp;
+        char const * pz;
+        tFpStack *   pfp = pCurFp;
+        char const * tpl_name = strrchr(pzTemplFileName, DIRCH);
+        if (tpl_name == NULL)
+            tpl_name = pzTemplFileName;
+        else
+            tpl_name++;
 
         while (pfp->flags & FPF_UNLINK)  pfp = pfp->pPrev;
         if (! ENABLED_OPT(DEFINITIONS))
@@ -210,8 +216,8 @@ ag_scm_dne(SCM prefix, SCM first, SCM opt)
         }
 
         pzRes = aprf(ENABLED_OPT(WRITABLE) ? zDne2 : zDne,
-                     pzPrefix, pfp->pzOutName, zScribble,
-                     pz, pzTemplFileName, pzFirst);
+                     pzPrefix, pfp->pzOutName, date_str,
+                     pz, tpl_name, pzFirst);
     }
 
     if (pzRes == NULL)
@@ -258,25 +264,27 @@ ag_scm_dne(SCM prefix, SCM first, SCM opt)
 SCM
 ag_scm_error(SCM res)
 {
-    tSCC      zFmt[]    = "DEFINITIONS %s in %s line %d for %s:\n\t%s\n";
-    tSCC      zErr[]    = "ERROR";
-    tSCC      zWarn[]   = "Warning";
-    tSCC      zBadMsg[] = "??? indecipherable error message ???";
-    tCC*      pzMsg;
-    tSuccess  abrt = FAILURE;
-    char      zNum[16];
-    int       msgLen;
+    static char const zErr[]    = "ERROR";
+    static char const zWarn[]   = "Warning";
+    static char const zBadMsg[] = "??? indecipherable error message ???";
+    static char const zFmt[]    =
+        "DEFINITIONS %s in %s line %d for %s:\n\t%s\n";
 
-    switch (gh_type_e(res)) {
+    char const *  pzMsg;
+    tSuccess      abrt = FAILURE;
+    char          zNum[16];
+    int           msgLen;
+
+    switch (ag_scm_type_e(res)) {
     case GH_TYPE_BOOLEAN:
-        if (SCM_FALSEP(res))
+        if (AG_SCM_FALSEP(res))
             abrt = PROBLEM;
         pzMsg = zNil;
         break;
 
     case GH_TYPE_NUMBER:
     {
-        unsigned long val = gh_scm2ulong(res);
+        unsigned long val = AG_SCM_TO_ULONG(res);
         if (val == 0)
             abrt = PROBLEM;
         snprintf(zNum, sizeof(zNum), "%d", (int)val);
@@ -285,7 +293,7 @@ ag_scm_error(SCM res)
     }
 
     case GH_TYPE_CHAR:
-        zNum[0] = gh_scm2char(res);
+        zNum[0] = AG_SCM_CHAR(res);
         if ((zNum[0] == NUL) || (zNum[0] == '0'))
             abrt = PROBLEM;
         zNum[1] = NUL;
@@ -477,8 +485,8 @@ ag_scm_license(SCM license, SCM prog_name, SCM owner, SCM prefix)
     char const * pzPrg   = ag_scm2zchars(prog_name, "program name");
     char const * pzOwner = ag_scm2zchars(owner,     "owner");
     static struct {
-        tCC*    pzFN;
-        tmap_info_t mi;
+        char const * pzFN;
+        tmap_info_t  mi;
     } lic = { NULL, { NULL, 0, 0, 0, 0, 0, 0, 0 }};
 
     char*     pzRes;
@@ -487,7 +495,7 @@ ag_scm_license(SCM license, SCM prog_name, SCM owner, SCM prefix)
         return SCM_UNDEFINED;
 
     {
-        tSCC*  apzSfx[] = { "lic", NULL };
+        static char const * apzSfx[] = { "lic", NULL };
         static char zRealFile[ AG_PATH_MAX ];
         char const * pzLicense = ag_scm2zchars(license, "license file");
 
