@@ -2,12 +2,12 @@
 /*
  *  expMake.c
  *
- *  Time-stamp:        "2010-02-24 08:42:59 bkorb"
+ *  Time-stamp:        "2011-01-20 16:22:01 bkorb"
  *
  *  This module implements Makefile construction functions.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -95,7 +95,7 @@
 SCM
 ag_scm_makefile_script(SCM text)
 {
-    tSCC   zNl[]  = " ; \\\n";
+    static char const zNl[]  = " ; \\\n";
 
     SCM    res;
     char*  pzText = ag_scm2zchars(text, "GPL line prefix");
