@@ -1,13 +1,13 @@
 
-/*
- *  $Id: 9701e2c63d3aee77b514f5800d7a576ad0ae154d $
- *
- *  Time-stamp:        "2010-02-24 08:42:11 bkorb"
+/**
+ * \file funcEval.c
  *
  *  This module evaluates macro expressions.
  *
+ *  Time-stamp:        "2011-01-20 16:07:46 bkorb"
+ *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -23,31 +23,35 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-static int exprType( char* pz );
-
 /* = = = START-STATIC-FORWARD = = = */
+static inline char const *
+tpl_text(tTemplate * tpl, tMacro * mac);
+
+static void
+tpl_warning(tTemplate * tpl, tMacro * mac, char const * msg);
+
 static int
-exprType( char* pz );
+exprType(char* pz);
 /* = = = END-STATIC-FORWARD = = = */
 
-LOCAL tCC*
-resolveSCM( SCM s )
+LOCAL char const *
+resolveSCM(SCM s)
 {
-    static char z[48];
-    tCC*  pzRes = z;
+    static char  z[48];
+    char const * pzRes = z;
 
-    switch (gh_type_e( s )) {
+    switch (ag_scm_type_e(s)) {
     case GH_TYPE_BOOLEAN:
-        z[0] = SCM_NFALSEP(s) ? '1' : '0'; z[1] = NUL;
+        z[0] = AG_SCM_NFALSEP(s) ? '1' : '0'; z[1] = NUL;
         break;
 
     case GH_TYPE_STRING:
     case GH_TYPE_SYMBOL:
-        pzRes = ag_scm2zchars( s, "SCM Result" );
+        pzRes = ag_scm2zchars(s, "SCM Result");
         break;
 
     case GH_TYPE_CHAR:
-        z[0] = gh_scm2char(s); z[1] = NUL; break;
+        z[0] = AG_SCM_CHAR(s); z[1] = NUL; break;
 
     case GH_TYPE_VECTOR:
         pzRes = "** Vector **"; break;
@@ -56,15 +60,15 @@ resolveSCM( SCM s )
         pzRes = "** Pair **"; break;
 
     case GH_TYPE_NUMBER:
-        snprintf( z, sizeof(z), "%ld", gh_scm2ulong(s) ); break;
+        snprintf(z, sizeof(z), "%ld", AG_SCM_TO_ULONG(s)); break;
 
     case GH_TYPE_PROCEDURE:
 #ifdef SCM_SUBR_ENTRY
     {
         void* x = &SCM_SUBR_ENTRY(s);
 
-        snprintf( z, sizeof(z), "** Procedure 0x%08lX **",
-                  (unsigned long)x );
+        snprintf(z, sizeof(z), "** Procedure 0x%08lX **",
+                 (unsigned long)x);
         break;
     }
 #else
@@ -91,31 +95,50 @@ resolveSCM( SCM s )
     return pzRes;
 }
 
+/**
+ * Return the text associated with a macro.
+ */
+static inline char const *
+tpl_text(tTemplate * tpl, tMacro * mac)
+{
+    if (mac->ozText == 0)
+        return zNil;
 
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
- *   Exported function procedures
- *
- *  evalExpression
- *
+    return tpl->pzTemplText + mac->ozText;
+}
+
+static void
+tpl_warning(tTemplate * tpl, tMacro * mac, char const * msg)
+{
+    fprintf(pfTrace, zTplWarn, tpl->pzTplFile, mac->lineNo, msg);
+}
+
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+/**
  *  Evaluate an expression and return a string pointer.  Always.
  *  It may need to be deallocated, so a boolean pointer is used
- *  to tell the caller.
+ *  to tell the caller.  Also, the match existence and non-existence
+ *  pay attention to the address of the empty string that gets
+ *  returned.  If it is, specifically, "zNil", then this code is
+ *  saying, "we could not compute a value, so we're returning this
+ *  empty string".  This is used by the Select_Match_Existence and
+ *  Select_Match_NonExistence code to distinguish non-existence from
+ *  an empty string value.
  */
-LOCAL tCC*
-evalExpression( ag_bool* pMustFree )
+LOCAL char const *
+evalExpression(ag_bool* pMustFree)
 {
-    tTemplate*  pT      = pCurTemplate;
-    tMacro*     pMac    = pCurMacro;
-    ag_bool     isIndexed;
-    tDefEntry*  pDef;
-    int         code    = pMac->res;
-    tCC*        pzText  = NULL; /* warning patrol */
+    tTemplate *   pT      = pCurTemplate;
+    tMacro *      pMac    = pCurMacro;
+    ag_bool       isIndexed;
+    tDefEntry *   pDef;
+    int           code    = pMac->res;
+    char const *  pzText  = NULL; /* warning patrol */
 
     *pMustFree = AG_FALSE;
 
     if ((code & EMIT_NO_DEFINE) != 0) {
-        pzText = pT->pzTemplText + pMac->ozText;
+        pzText = tpl_text(pT, pMac);
         code  &= EMIT_PRIMARY_TYPE;
         pDef   = NULL; /* warning patrol */
     }
@@ -124,7 +147,7 @@ evalExpression( ag_bool* pMustFree )
         /*
          *  Get the named definition entry, maybe
          */
-        pDef = findDefEntry( pT->pzTemplText + pMac->ozName, &isIndexed );
+        pDef = findDefEntry(pT->pzTemplText + pMac->ozName, &isIndexed);
 
         if (pDef == NULL) {
             switch (code & (EMIT_IF_ABSENT | EMIT_ALWAYS)) {
@@ -133,7 +156,7 @@ evalExpression( ag_bool* pMustFree )
                  *  There is only one expression.  It applies because
                  *  we did not find a definition.
                  */
-                pzText = pT->pzTemplText + pMac->ozText;
+                pzText = tpl_text(pT, pMac);
                 code &= EMIT_PRIMARY_TYPE;
                 break;
 
@@ -156,7 +179,7 @@ evalExpression( ag_bool* pMustFree )
                 /*
                  *  Emit inconsistently :-}
                  */
-                AG_ABEND_IN( pT, pMac, "PROGRAM ERROR:  ambiguous expr code" );
+                AG_ABEND_IN(pT, pMac, "PROGRAM ERROR:  ambiguous expr code");
                 /* NOTREACHED */
             }
         }
@@ -165,15 +188,15 @@ evalExpression( ag_bool* pMustFree )
          *  OTHERWISE, we found an entry.  Make sure we were supposed to.
          */
         else {
-            tSCC zBlock[] = "attempted to use block macro in eval expression";
+            static char const zBlock[] =
+                "attempted to use block macro in eval expression";
 
             if ((code & EMIT_IF_ABSENT) != 0)
                 return (char*)zNil;
 
             if (  (pDef->valType != VALTYP_TEXT)
                && ((code & EMIT_PRIMARY_TYPE) == EMIT_VALUE)  ) {
-                fprintf( pfTrace, zTplWarn, pT->pzTplFile, pMac->lineNo,
-                         zBlock );
+                tpl_warning(pT, pMac, zBlock);
                 return (char*)zNil;
             }
 
@@ -193,13 +216,12 @@ evalExpression( ag_bool* pMustFree )
                  *  And make sure what we found is a text value
                  */
                 if (pDef->valType != VALTYP_TEXT) {
-                    fprintf( pfTrace, zTplWarn, pT->pzTplFile, pMac->lineNo,
-                             zBlock );
+                    tpl_warning(pT, pMac, zBlock);
                     return (char*)zNil;
                 }
 
                 *pMustFree = AG_TRUE;
-                pzText = aprf(pT->pzTemplText + pMac->ozText, pDef->val.pzText);
+                pzText = aprf(tpl_text(pT, pMac), pDef->val.pzText);
             }
 
             else if (pMac->ozText != 0)
@@ -210,8 +232,7 @@ evalExpression( ag_bool* pMustFree )
                  *  And make sure what we found is a text value
                  */
                 if (pDef->valType != VALTYP_TEXT) {
-                    fprintf( pfTrace, zTplWarn, pT->pzTplFile, pMac->lineNo,
-                             zBlock );
+                    tpl_warning(pT, pMac, zBlock);
                     return (char*)zNil;
                 }
 
@@ -229,7 +250,7 @@ evalExpression( ag_bool* pMustFree )
     case EMIT_VALUE:
         assert(pDef != NULL);
         if (*pMustFree) {
-            AGFREE( (void*)pzText );
+            AGFREE((void*)pzText);
             *pMustFree = AG_FALSE;
         }
 
@@ -238,23 +259,23 @@ evalExpression( ag_bool* pMustFree )
 
     case EMIT_EXPRESSION:
     {
-        SCM res = ag_eval( pzText );
+        SCM res = ag_eval(pzText);
 
         if (*pMustFree) {
-            AGFREE( (void*)pzText );
+            AGFREE((void*)pzText);
             *pMustFree = AG_FALSE;
         }
 
-        pzText = resolveSCM( res );
+        pzText = resolveSCM(res);
         break;
     }
 
     case EMIT_SHELL:
     {
-        char* pz = runShell( pzText );
+        char* pz = runShell(pzText);
 
         if (*pMustFree)
-            AGFREE( (void*)pzText );
+            AGFREE((void*)pzText);
 
         if (pz != NULL) {
             *pMustFree = AG_TRUE;
@@ -285,12 +306,14 @@ evalExpression( ag_bool* pMustFree )
  *       invoke this routine directly.  Guile will do it automatically.
 =*/
 SCM
-ag_scm_error_source_line( void )
+ag_scm_error_source_line(void)
 {
-    tSCC zErr[] = "\nGuile/Scheme evaluation error in %s line %d:  %s\n";
-    fprintf( stderr, zErr, pCurTemplate->pzTplName, pCurMacro->lineNo,
-             pCurTemplate->pzTemplText + pCurMacro->ozText );
-    fflush( stderr );
+    static char const zErr[] =
+        "\nGuile/Scheme evaluation error in %s line %d:  %s\n";
+
+    fprintf(stderr, zErr, pCurTemplate->pzTplName, pCurMacro->lineNo,
+            pCurTemplate->pzTemplText + pCurMacro->ozText);
+    fflush(stderr);
     guileFailure = 1;
 
     return SCM_UNDEFINED;
@@ -310,7 +333,7 @@ ag_scm_error_source_line( void )
  *       the current output.
 =*/
 SCM
-ag_scm_emit( SCM val )
+ag_scm_emit(SCM val)
 {
     static int depth = 0;
     static FILE * fp;
@@ -325,12 +348,13 @@ ag_scm_emit( SCM val )
             break;
 
         pSaveFp = pCurFp;
-        pnum    = gh_scm2ulong(val);
+        pnum    = AG_SCM_TO_ULONG(val);
 
         for (; pnum > 0; pnum--) {
             pSaveFp = pSaveFp->pPrev;
             if (pSaveFp == NULL)
-                AG_ABEND(aprf("invalid emission port: %d", gh_scm2ulong(val)));
+                AG_ABEND(aprf("invalid emission port: %d",
+                              AG_SCM_TO_ULONG(val)));
         }
 
         fp = pSaveFp->pFile;
@@ -347,25 +371,25 @@ ag_scm_emit( SCM val )
         if (val == SCM_UNDEFINED)
             break;
 
-        if (SCM_NULLP( val ))
+        if (AG_SCM_NULLP(val))
             break;
 
-        if (AG_SCM_STRING_P( val )) {
-            fputs( (char*)ag_scm2zchars( val, "emit val" ), fp );
-            fflush( fp );
+        if (AG_SCM_STRING_P(val)) {
+            fputs((char*)ag_scm2zchars(val, "emit val"), fp);
+            fflush(fp);
             break;
         }
 
-        switch (gh_type_e( val )) {
+        switch (ag_scm_type_e(val)) {
         case GH_TYPE_LIST:
         case GH_TYPE_PAIR:
-            ag_scm_emit( SCM_CAR( val ));
-            val = SCM_CDR( val );
+            ag_scm_emit(SCM_CAR(val));
+            val = SCM_CDR(val);
             continue;
 
         default:
-            fputs( resolveSCM( val ), fp );
-            fflush( fp );
+            fputs(resolveSCM(val), fp);
+            fflush(fp);
             break;
         }
 
@@ -389,7 +413,7 @@ ag_scm_emit( SCM val )
  *  the string.
  */
 LOCAL SCM
-eval( char const* pzExpr )
+eval(char const* pzExpr)
 {
     ag_bool allocated = AG_FALSE;
     char*   pzTemp;
@@ -398,30 +422,30 @@ eval( char const* pzExpr )
     switch (*pzExpr) {
     case '(':
     case ';':
-        res = ag_eval( (char*)pzExpr );
+        res = ag_eval((char*)pzExpr);
         break;
 
     case '`':
-        AGDUPSTR( pzTemp, pzExpr, "shell script" );
-        (void)spanQuote( pzTemp );
-        pzExpr = runShell( pzTemp );
-        AGFREE( (void*)pzTemp );
-        res = AG_SCM_STR02SCM( (char*)pzExpr );
-        AGFREE( (void*)pzExpr );
+        AGDUPSTR(pzTemp, pzExpr, "shell script");
+        (void)spanQuote(pzTemp);
+        pzExpr = runShell(pzTemp);
+        AGFREE((void*)pzTemp);
+        res = AG_SCM_STR02SCM((char*)pzExpr);
+        AGFREE((void*)pzExpr);
         break;
 
     case '"':
     case '\'':
-        AGDUPSTR( pzTemp, pzExpr, "quoted string" );
-        (void)spanQuote( pzTemp );
+        AGDUPSTR(pzTemp, pzExpr, "quoted string");
+        (void)spanQuote(pzTemp);
         allocated = AG_TRUE;
         pzExpr = pzTemp;
         /* FALLTHROUGH */
 
     default:
-        res = AG_SCM_STR02SCM( (char*)pzExpr );
+        res = AG_SCM_STR02SCM((char*)pzExpr);
         if (allocated)
-            AGFREE( (void*)pzExpr );
+            AGFREE((void*)pzExpr);
     }
 
     return res;
@@ -444,22 +468,25 @@ eval( char const* pzExpr )
  *   (@pxref{expression syntax}) is written to the current output.
 =*/
 tMacro*
-mFunc_Expr( tTemplate* pT, tMacro* pMac )
+mFunc_Expr(tTemplate* pT, tMacro* pMac)
 {
     ag_bool needFree;
-    tCC* pz = evalExpression( &needFree );
+    char const * pz = evalExpression(&needFree);
+
+    if (*pz != NUL) {
+        fputs(pz, pCurFp->pFile);
+        fflush(pCurFp->pFile);
+    }
 
-    fputs( pz, pCurFp->pFile );
-    fflush( pCurFp->pFile );
     if (needFree)
-        AGFREE( (void*)pz );
+        AGFREE((void*)pz);
 
     return pMac + 1;
 }
 
 
 static int
-exprType( char* pz )
+exprType(char* pz)
 {
     switch (*pz) {
     case ';':
@@ -467,12 +494,12 @@ exprType( char* pz )
         return EMIT_EXPRESSION;
 
     case '`':
-        spanQuote( pz );
+        spanQuote(pz);
         return EMIT_SHELL;
 
     case '"':
     case '\'':
-        spanQuote( pz );
+        spanQuote(pz);
         /* FALLTHROUGH */
 
     default:
@@ -485,13 +512,13 @@ exprType( char* pz )
  *  mLoad_Expression
  */
 tMacro*
-mLoad_Expr( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
+mLoad_Expr(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
 {
-    char*    pzCopy; /* next text dest   */
-    tCC*     pzSrc  = (char const*)pMac->ozText; /* macro text */
-    size_t   srcLen = (long)pMac->res;           /* macro len  */
-    tCC*     pzSrcEnd = pzSrc + srcLen;
-    tMacro*  pNextMac;
+    char *        pzCopy; /* next text dest   */
+    char const *  pzSrc    = (char const*)pMac->ozText; /* macro text */
+    size_t        srcLen   = (long)pMac->res;           /* macro len  */
+    char const *  pzSrcEnd = pzSrc + srcLen;
+    tMacro *      pNextMac;
 
     switch (*pzSrc) {
     case '-':
@@ -514,21 +541,21 @@ mLoad_Expr( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         break;
 
     case '`':
-        pNextMac  = mLoad_Unknown( pT, pMac, ppzScan );
+        pNextMac  = mLoad_Unknown(pT, pMac, ppzScan);
         pMac->res = EMIT_NO_DEFINE | EMIT_SHELL;
-        spanQuote( pT->pzTemplText + pMac->ozText );
+        spanQuote(pT->pzTemplText + pMac->ozText);
         return pNextMac;
 
     case '"':
     case '\'':
-        pNextMac  = mLoad_Unknown( pT, pMac, ppzScan );
+        pNextMac  = mLoad_Unknown(pT, pMac, ppzScan);
         pMac->res = EMIT_NO_DEFINE | EMIT_STRING;
-        spanQuote( pT->pzTemplText + pMac->ozText );
+        spanQuote(pT->pzTemplText + pMac->ozText);
         return pNextMac;
 
     case '(':
     case ';':
-        pNextMac  = mLoad_Unknown( pT, pMac, ppzScan );
+        pNextMac  = mLoad_Unknown(pT, pMac, ppzScan);
         pMac->res = EMIT_NO_DEFINE | EMIT_EXPRESSION;
         return pNextMac;
 
@@ -539,17 +566,17 @@ mLoad_Expr( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     pzCopy = pT->pNext;
     pMac->ozName = (pzCopy - pT->pzTemplText);
     {
-        size_t remLen = canonicalizeName( pzCopy, pzSrc, (int)srcLen );
+        size_t remLen = canonicalizeName(pzCopy, pzSrc, (int)srcLen);
         if (remLen > srcLen)
-            AG_ABEND_IN( pT, pMac, "Invalid definition name" );
+            AG_ABEND_IN(pT, pMac, "Invalid definition name");
         pzSrc  += srcLen - remLen;
         srcLen  = remLen;
-        pzCopy += strlen( pzCopy )+1;
+        pzCopy += strlen(pzCopy) + 1;
     }
 
     if (pzSrc >= pzSrcEnd) {
         if (pMac->res != EMIT_VALUE)
-            AG_ABEND_IN( pT, pMac, "No text for unfound value" );
+            AG_ABEND_IN(pT, pMac, "No text for unfound value");
 
         pMac->ozText = 0;
 
@@ -569,16 +596,16 @@ mLoad_Expr( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
          *  THEN find the ending expression...
          */
         if ((pMac->res & EMIT_ALWAYS) != 0) {
-            char* pzNextExpr = (char*)skipExpression( pz, srcLen );
+            char* pzNextExpr = (char*)skipExpression(pz, srcLen);
 
             /*
              *  The next expression must be within bounds and space separated
              */
             if (pzNextExpr >= pz + srcLen)
-                AG_ABEND_IN( pT, pMac, "`?' needs two expressions" );
+                AG_ABEND_IN(pT, pMac, "`?' needs two expressions");
 
             if (! IS_WHITESPACE_CHAR(*pzNextExpr))
-                AG_ABEND_IN( pT, pMac, "No space between expressions" );
+                AG_ABEND_IN(pT, pMac, "No space between expressions");
 
             /*
              *  NUL terminate the first expression, skip intervening
@@ -587,11 +614,11 @@ mLoad_Expr( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
              */
             *(pzNextExpr++) = NUL;
             while (IS_WHITESPACE_CHAR(*pzNextExpr))  pzNextExpr++;
-            pMac->res |= (exprType( pzNextExpr ) << EMIT_SECONDARY_SHIFT);
+            pMac->res |= (exprType(pzNextExpr) << EMIT_SECONDARY_SHIFT);
             pMac->endIndex = pzNextExpr - pT->pzTemplText;
         }
 
-        pMac->res |= exprType( pz );
+        pMac->res |= exprType(pz);
     }
 
     pT->pNext = pzCopy;
