@@ -2,12 +2,12 @@
 /**
  * \file tpLoad.c
  *
- * Time-stamp:        "2010-12-09 19:10:18 bkorb"
+ * Time-stamp:        "2011-01-20 16:18:51 bkorb"
  *
  *  This module will load a template and return a template structure.
  *
  * This file is part of AutoGen.
- * AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ * AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -323,7 +323,8 @@ load_macs(tTemplate * pT, char const * pzF, char const * pzN,
      */
 #if defined(DEBUG_ENABLED)
     if (HAVE_OPT(SHOW_DEFS)) {
-        tSCC zSum[] = "loaded %d macros from %s\n"
+        static char const zSum[] =
+            "loaded %d macros from %s\n"
             "\tBinary template size:  0x%zX\n\n";
         fprintf(pfTrace, zSum, pT->macroCt, pzF, pT->descSize);
     }
@@ -540,7 +541,7 @@ wrap_up_depends(void)
          * file exists and set its time to the same time.  Ignore all errors.
          */
         if (strcmp(pzDepFile, pzDepTarget) != 0) {
-            if (! access(pzDepTarget, R_OK))
+            if (access(pzDepTarget, R_OK) != 0)
                 close( open(pzDepTarget, O_CREAT, fil_mode));
 
             utime(pzDepTarget, &tbuf);
