@@ -3,12 +3,12 @@
  *  tpParse.c
  *
  *
- * Time-stamp:        "2010-06-30 21:25:54 bkorb"
+ * Time-stamp:        "2011-01-27 12:50:33 bkorb"
  *
  *  This module will load a template and return a template structure.
  *
  * This file is part of AutoGen.
- * AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ * AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -27,7 +27,7 @@
 #if defined(DEBUG_ENABLED)
 static int tplNestLevel = 0;
 
-tSCC zTDef[] = "%-10s (%d) line %d end=%d, strlen=%d\n";
+static char const zTDef[] = "%-10s (%d) line %d end=%d, strlen=%d\n";
 #endif
 
 /* = = = START-STATIC-FORWARD = = = */
@@ -39,6 +39,9 @@ find_mac_end(char const ** ppzMark);
 
 static char const *
 find_mac_start(char const * pz, tMacro** ppM, tTemplate* pTpl);
+
+static char const *
+find_macro(tTemplate * pTpl, tMacro ** ppM, char const ** ppzScan);
 /* = = = END-STATIC-FORWARD = = = */
 
 /*
@@ -48,10 +51,10 @@ find_mac_start(char const * pz, tMacro** ppM, tTemplate* pTpl);
 static teFuncType
 func_code(char const ** ppzScan)
 {
-    char const *   pzFuncName = *ppzScan;
-    int           hi, lo, av;
-    tNameType*    pNT;
-    int           cmp;
+    tNameType const * pNT;
+    char const *      pzFuncName = *ppzScan;
+    int               hi, lo, av;
+    int               cmp;
 
     /*
      *  IF the name starts with a punctuation, then it is some sort of
@@ -235,6 +238,82 @@ find_mac_start(char const * pz, tMacro** ppM, tTemplate* pTpl)
     return res;  /* may be NULL, if there are no more macros */
 }
 
+static char const *
+find_macro(tTemplate * pTpl, tMacro ** ppM, char const ** ppzScan)
+{
+    char const * pzScan = *ppzScan;
+    char const * pzMark;
+
+    pzMark = find_mac_start(pzScan, ppM, pTpl);
+
+    /*
+     *  IF no more macro marks are found, THEN we are done...
+     */
+    if (pzMark == NULL)
+        return pzMark;
+
+    /*
+     *  Find the macro code and the end of the macro invocation
+     */
+    pCurMacro = *ppM;
+    pzScan    = find_mac_end(&pzMark);
+
+    /*
+     *  Count the lines in the macro text and advance the
+     *  text pointer to after the marker.
+     */
+    {
+        char const *  pzMacEnd = pzScan;
+        char const *  pz       = pzMark;
+
+        for (;;pz++) {
+            pz = strchr(pz, '\n');
+            if ((pz == NULL) || (pz > pzMacEnd))
+                break;
+            templLineNo++;
+        }
+
+        /*
+         *  Strip white space from the macro
+         */
+        while ((pzMark < pzMacEnd) && IS_WHITESPACE_CHAR(*pzMark))
+            pzMark++;
+        while ((pzMacEnd > pzMark) && IS_WHITESPACE_CHAR(pzMacEnd[-1]))
+            pzMacEnd--;
+
+        if (pzMark != pzMacEnd) {
+            (*ppM)->ozText = (uintptr_t)pzMark;
+            (*ppM)->res    = (long)(pzMacEnd - pzMark);
+        }
+    }
+
+    /*
+     *  IF the end macro mark was preceded by a backslash, then we remove
+     *  trailing white space from there to the end of the line.
+     */
+    if ((*pzScan != '\\') || (strncmp(zEndMac, pzScan, endMacLen) == 0))
+        pzScan += endMacLen;
+
+    else {
+        char const * pz = (pzScan += endMacLen + 1);
+
+        /*
+         *  We are eating white space, do so only if there is white space
+         *  from the end macro marker to EOL.  Anything else on the line
+         *  will suppress the feature.
+         */
+        while (IS_WHITESPACE_CHAR(*pz)) {
+            if (*(pz++) == '\n') {
+                templLineNo++;
+                pzScan = pz;
+                break;
+            }
+        }
+    }
+
+    *ppzScan = pzScan;
+    return pzMark;
+}
 
 LOCAL tMacro*
 parseTemplate(tMacro* pM, char const ** ppzText)
@@ -243,7 +322,7 @@ parseTemplate(tMacro* pM, char const ** ppzText)
     tTemplate* pTpl = pCurTemplate;
 
 #if defined(DEBUG_ENABLED)
-    tSCC zTUndef[] = "%-10s (%d) line %d - MARKER\n";
+    static char const zTUndef[] = "%-10s (%d) line %d - MARKER\n";
 
     #define DEBUG_DEC(l)  l--
 
@@ -263,81 +342,17 @@ parseTemplate(tMacro* pM, char const ** ppzText)
 #endif
 
     for (;;) {
-        char const * pzMark = find_mac_start(pzScan, &pM, pTpl);
-
-        /*
-         *  IF no more macro marks are found,
-         *  THEN we are done...
-         */
+        char const * pzMark = find_macro(pTpl, &pM, &pzScan);
         if (pzMark == NULL)
             break;
 
-        /*
-         *  Find the macro code and the end of the macro invocation
-         */
-        pCurMacro = pM;
-        pzScan = find_mac_end(&pzMark);
-
-        /*
-         *  Count the lines in the macro text and advance the
-         *  text pointer to after the marker.
-         */
-        {
-            char const *  pzMacEnd = pzScan;
-            char const *  pz       = pzMark;
-
-            for (;;pz++) {
-                pz = strchr(pz, '\n');
-                if ((pz == NULL) || (pz > pzMacEnd))
-                    break;
-                templLineNo++;
-            }
-
-            /*
-             *  Strip white space from the macro
-             */
-            while ((pzMark < pzMacEnd) && IS_WHITESPACE_CHAR(*pzMark))
-                pzMark++;
-            while ((pzMacEnd > pzMark) && IS_WHITESPACE_CHAR(pzMacEnd[-1]))
-                pzMacEnd--;
-
-            if (pzMark != pzMacEnd) {
-                pM->ozText = (uintptr_t)pzMark;
-                pM->res    = (long)(pzMacEnd - pzMark);
-            }
-        }
-
-        /*
-         *  IF the end macro mark was preceded by a backslash, then we remove
-         *  trailing white space from there to the end of the line.
-         */
-        if ((*pzScan != '\\') || (strncmp(zEndMac, pzScan, endMacLen) == 0))
-            pzScan += endMacLen;
-
-        else {
-            char const * pz = (pzScan += endMacLen + 1);
-
-            /*
-             *  We are eating white space, do so only if there is white space
-             *  from the end macro marker to EOL.  Anything else on the line
-             *  will suppress the feature.
-             */
-            while (IS_WHITESPACE_CHAR(*pz)) {
-                if (*(pz++) == '\n') {
-                    templLineNo++;
-                    pzScan = pz;
-                    break;
-                }
-            }
-        }
-
         /*
          *  IF the called function returns a NULL next macro pointer,
          *  THEN some block has completed.  The returned scanning pointer
          *       will be non-NULL.
          */
         {
-            tMacro* pNM = (*(papLoadProc[ pM->funcCode ]))(pTpl, pM, &pzScan);
+            tMacro * pNM = (*(papLoadProc[ pM->funcCode]))(pTpl, pM, &pzScan);
 
 #if defined(DEBUG_ENABLED)
             if (HAVE_OPT(SHOW_DEFS)) {
